@@ -1,8 +1,8 @@
 # 正規表現でtextファイルと同じやり方で読み込むのですべて手打ちする．
 
-from .ternary_diagram import *
+from .ternary_diagram import TernaryDiagram
 
-__version__      = '1.5.6'
+__version__      = '2.0.1'
 __license__      = 'MIT'
 __author__       = 'yu9824'
 __copyright__ = 'Copyright © 2021 yu9824'
